@@ -198,21 +198,11 @@ class BaseCfgLine(object):
         """Delete any child :class:`~models_cisco.IOSCfgLine` objects which 
         match ``linespec``.
 
-        Parameters
-        ----------
+        Args:
+            linespec (str): A string or python regular expression, which should be matched.  
 
-        linespec : str, required
-             A string or python regular expression, which should be matched.  
-
-        Returns
-        -------
-
-        list
-            A list of :class:`~models_cisco.IOSCfgLine` objects which were 
-            deleted.
-
-        Examples
-        --------
+        Returns:
+            list.  A list of :class:`~models_cisco.IOSCfgLine` objects which were deleted.
 
         This example illustrates how you can use 
         :func:`~ccp_abc.delete_children_matching` to delete any description 
@@ -276,23 +266,12 @@ class BaseCfgLine(object):
         """Append an :class:`~models_cisco.IOSCfgLine` object with ``insertstr``
         to the bottom of the current configuration family.
 
-        Parameters
-        ----------
+        Args:
+            insertstr (str): A string which contains the text configuration to be apppended.
 
-        insertstr : str, required
-             A string which contains the text configuration to be apppended.
-        default : str, optional
-             A string which contains the text default value
-
-        Returns
-        -------
-
-        str
-            The text matched by the regular expression group; if there is no
-            match, None is returned.
-
-        Examples
-        --------
+        Returns:
+            str.  The text matched by the regular expression group; if there 
+            is no match, None is returned.
 
         This example illustrates how you can use 
         :func:`~ccp_abc.append_to_family` to add a 
@@ -344,29 +323,18 @@ class BaseCfgLine(object):
         the text is *not* replaced.  The ``replace()`` method is simply an 
         alias to the ``re_sub()`` method.
 
-        Parameters
-        ----------
+        Args:
+            linespec (str): A string or python regular expression, which should be matched
+            replacestr (str): A string or python regular expression, which should replace the
+                 text matched by ``linespec``.
+        Kwargs:
+            ignore_rgx (str): A string or python regular expression; the replacement is skipped
+                 if :class:`~models_cisco.IOSCfgLine` text matches ``ignore_rgx``.
+                 ``ignore_rgx`` defaults to None, which means no lines matching
+                 ``linespec`` are skipped.
 
-        linespec : str, required
-             A string or python regular expression, which should be matched
-        replacestr : str, required
-             A string or python regular expression, which should replace the
-             text matched by ``linespec``.
-        ignore_rgx : str, optional
-             A string or python regular expression; the replacement is skipped
-             if :class:`~models_cisco.IOSCfgLine` text matches ``ignore_rgx``.
-             ``ignore_rgx`` defaults to None, which means no lines matching
-             ``linespec`` are skipped.
-             
-
-        Returns
-        -------
-
-        str
-            The new text after replacement
-
-        Examples
-        --------
+        Returns:
+            str.  The new text after replacement
 
         This example illustrates how you can use 
         :func:`~models_cisco.IOSCfgLine.replace` to replace ``Serial1`` with 
@@ -403,29 +371,19 @@ class BaseCfgLine(object):
     def re_sub(self, regex, replacergx, ignore_rgx=None):
         """Replace all strings matching ``linespec`` with ``replacestr`` in the :class:`~models_cisco.IOSCfgLine` object; however, if the :class:`~models_cisco.IOSCfgLine` text matches ``ignore_rgx``, then the text is *not* replaced.
 
-        Parameters
-        ----------
-
-        linespec : str, required
-             A string or python regular expression, which should be matched
-        replacestr : str, required
-             A string or python regular expression, which should replace the
-             text matched by ``linespec``.
-        ignore_rgx : str, optional
-             A string or python regular expression; the replacement is skipped
-             if :class:`~models_cisco.IOSCfgLine` text matches ``ignore_rgx``.
-             ``ignore_rgx`` defaults to None, which means no lines matching
-             ``linespec`` are skipped.
+        Args:
+            linespec (str): A string or python regular expression, which should be matched
+            replacestr (str): A string or python regular expression, which should replace the
+                text matched by ``linespec``.
+        Kwargs:
+            ignore_rgx (str): A string or python regular expression; the replacement is skipped
+                if :class:`~models_cisco.IOSCfgLine` text matches ``ignore_rgx``.
+                ``ignore_rgx`` defaults to None, which means no lines matching
+                ``linespec`` are skipped.
              
 
-        Returns
-        -------
-
-        str
-            The new text after replacement
-
-        Examples
-        --------
+        Returns:
+            str.  The new text after replacement
 
         This example illustrates how you can use 
         :func:`~models_cisco.IOSCfgLine.re_sub` to replace ``Serial1`` with 
@@ -473,29 +431,19 @@ class BaseCfgLine(object):
     def re_match(self, regex, group=1, default=""):
         """Use ``regex`` to search the :class:`~models_cisco.IOSCfgLine` text and return the regular expression group, at the integer index.
 
-        Parameters
-        ----------
+        Args:
+            regex (str): A string or python regular expression, which should be matched.  
+                 This regular expression should contain parenthesis, which bound a 
+                 match group.
+        Kwargs:
+            group (int): An integer which specifies the desired group to be returned.
+                ``group`` defaults to 1.
+            default (str): The default value to be returned, if there is no match.  By default
+                 an empty string is returned if there is no match.
 
-        regex : str, required
-             A string or python regular expression, which should be matched.  
-             This regular expression should contain parenthesis, which bound a 
-             match group.
-        group : int, optional
-             An integer which specifies the desired group to be returned.
-             ``group`` defaults to 1.
-        default : optional
-             The default value to be returned, if there is no match.  By default
-             an empty string is returned if there is no match.
-
-        Returns
-        -------
-
-        str
-            The text matched by the regular expression group; if there is no
-            match, ``default`` is returned.
-
-        Examples
-        --------
+        Returns:
+            str.  The text matched by the regular expression group; if there is no
+                match, ``default`` is returned.
 
         This example illustrates how you can use 
         :func:`~models_cisco.IOSCfgLine..re_match` to store the mask of the 
@@ -531,21 +479,16 @@ class BaseCfgLine(object):
         """Use ``regex`` to search this :class:`~models_cisco.IOSCfgLine`'s
         text.
 
-        Parameters
-        ----------
+        Args:
+            regex (str):
+                 A string or python regular expression, which should be matched.  
+        Kwargs:
+            default (str): A value which is returned if :func:`~ccp_abc.re_search()` doesn't 
+                 find a match while looking for ``regex``.
 
-        regex : str, required
-             A string or python regular expression, which should be matched.  
-        default : optional
-             A value which is returned if :func:`~ccp_abc.re_search()` doesn't 
-             find a match while looking for ``regex``.
-
-        Returns
-        -------
-
-        str
-            The :class:`~models_cisco.IOSCfgLine` text which matched.  If 
-            there is no match, ``default`` is returned.
+        Returns:
+            str.  The :class:`~models_cisco.IOSCfgLine` text which matched.  If 
+                there is no match, ``default`` is returned.
         """
         ## TODO: use re.escape(regex) on all regex, instead of bare regex
         mm = re.search(regex, self.text)
@@ -557,19 +500,13 @@ class BaseCfgLine(object):
         """Use ``regex`` to search the text contained in the children of 
         this :class:`~models_cisco.IOSCfgLine`.
 
-        Parameters
-        ----------
+        Args:
+            regex (str): A string or python regular expression, which should be matched.  
 
-        regex : str, required
-             A string or python regular expression, which should be matched.  
-
-        Returns
-        -------
-
-        list
-            A list of matching :class:`~models_cisco.IOSCfgLine` objects which 
-            matched.  If there is no match, an empty :py:func:`list` is 
-            returned.
+        Returns:
+            list.  A list of matching :class:`~models_cisco.IOSCfgLine` objects which 
+                matched.  If there is no match, an empty :py:func:`list` is 
+                returned.
         """
         retval = list()
         for cobj in self.children:
@@ -583,32 +520,19 @@ class BaseCfgLine(object):
         integer index, cast as ``result_type``; if there is no match, 
         ``default`` is returned.
 
-        Parameters
-        ----------
+        Args:
+            regex (str): A string or python regular expression, which should be matched.  
+                 This regular expression should contain parenthesis, which bound a 
+                 match group.
+        Kwargs:
+            group (int): An integer which specifies the desired group to be returned.
+                 ``group`` defaults to 1.
+            result_type (type): A type (typically one of: ``str``, ``int``, ``float``, or ``IPv4Obj``).  All returned values are cast as ``result_type``, which defaults to ``str``.
+            default (any): The default value to be returned, if there is no match.
 
-        regex : str, required
-             A string or python regular expression, which should be matched.  
-             This regular expression should contain parenthesis, which bound a 
-             match group.
-        group : int, optional
-             An integer which specifies the desired group to be returned.
-             ``group`` defaults to 1.
-        result_type : type, optional
-             A type (typically one of: ``str``, ``int``, ``float``, or ``IPv4Obj``).         All returned values are cast as ``result_type``, which defaults 
-             to ``str``.
-        default : optional
-             The default value to be returned, if there is no match.
-
-        Returns
-        -------
-
-        ``result_type``
-            The text matched by the regular expression group; if there is no
-            match, ``default`` is returned.  All values are cast as 
-            ``result_type``.
-
-        Examples
-        --------
+        Returns:
+            ``result_type``.  The text matched by the regular expression group; if there is no
+                match, ``default`` is returned.  All values are cast as ``result_type``.
 
         This example illustrates how you can use 
         :func:`~models_cisco.IOSCfgLine.re_match_typed` to build an 
@@ -658,32 +582,18 @@ class BaseCfgLine(object):
         integer index, cast as ``result_type``; if there is no match, 
         ``default`` is returned.
 
-        Parameters
-        ----------
+        Args:
+            regex (str): A string or python regular expression, which should be matched.  
+                 This regular expression should contain parenthesis, which bound a 
+                 match group.
+        Kwargs:
+            group (int): An integer which specifies the desired group to be returned.
+                 ``group`` defaults to 1.
+            result_type (type): A type (typically one of: ``str``, ``int``, ``float``, or ``IPv4Obj``).         All returned values are cast as ``result_type``, which defaults to ``str``.
+            default (any): The default value to be returned, if there is no match.
 
-        regex : str, required
-             A string or python regular expression, which should be matched.  
-             This regular expression should contain parenthesis, which bound a 
-             match group.
-        group : int, optional
-             An integer which specifies the desired group to be returned.
-             ``group`` defaults to 1.
-        result_type : type, optional
-             A type (typically one of: ``str``, ``int``, ``float``, or ``IPv4Obj``).         All returned values are cast as ``result_type``, which defaults 
-             to ``str``.
-        default : optional
-             The default value to be returned, if there is no match.
-
-        Returns
-        -------
-
-        ``result_type``
-            The text matched by the regular expression group; if there is no
-            match, ``default`` is returned.  All values are cast as 
-            ``result_type``.
-
-        Examples
-        --------
+        Returns:
+            ``result_type``.  The text matched by the regular expression group; if there is no match, ``default`` is returned.  All values are cast as ``result_type``.
 
         This example illustrates how you can use 
         :func:`~models_cisco.IOSCfgLine.re_match_iter_typed` to build an 
