@@ -426,6 +426,9 @@ class ASAObjService(ASACfgLine):
 ##-------------  ASA object-group network
 ##
 
+_RE_NETHOST = re.compile(r'^\s*network-object\s+host\s+(\S+)')
+_RE_NETWORK1 = re.compile(r'^\s*network-object\s+(\S+)')
+_RE_NETWORK2 = re.compile(r'^\s*network-object\s+\S+\s+(\d+\.\d+\.\d+\.\d+)')
 class ASAObjGroupNetwork(ASACfgLine):
 
     def __init__(self, *args, **kwargs):
@@ -451,23 +454,28 @@ class ASAObjGroupNetwork(ASACfgLine):
         names = self.confobj.names
         for obj in self.children:
             if 'network-object host ' in obj.text:
-                host_str = obj.re_match_typed(r'^\s*network-object\s+host\s+(\S+)', 
-                    group=1, result_type=str)
+                host_str = obj.re_match_typed(_RE_NETHOST, group=1, result_type=str)
                 retval.append(IPv4Obj(names.get(host_str, host_str)))
             elif 'network-object ' in obj.text:
-                network_str = obj.re_match_typed(r'^\s*network-object\s+(\S+)', 
-                    group=1, result_type=str)
-                netmask_str = obj.re_match_typed(r'^\s*network-object\s+\S+\s+(\d+\.\d+\.\d+\.\d+)', 
-                    group=1, result_type=str)
+                network_str = obj.re_match_typed(_RE_NETWORK1, group=1, result_type=str)
+                netmask_str = obj.re_match_typed(_RE_NETWORK2, group=1, result_type=str)
                 retval.append(IPv4Obj('{0} {1}'.format(names.get(network_str, 
                     network_str), netmask_str)))
-            elif 'description ' in obj.text:
-                pass
             elif 'group-object ' in obj.text:
+                name = obj.re_match_typed(r'^\s*group-object\s+(\S+)', group=1, 
+                    result_type=str)
+                group_nets = self.confobj.object_group_network.get(name, None)
+                if name==self.name:
+                    ## Throw an error when importing self
+                    raise ValueError("FATAL: Cannot recurse through group-object {0} in object-group network {1}".format(name, self.name))
+                if (group_nets is None):
+                    raise ValueError("FATAL: Cannot find group-object named {0}".format(name))
+                else:
+                    retval.extend(group_nets.networks)
+            elif 'description ' in obj.text:
                 pass
             else:
                 raise NotImplementedError("Cannot parse '{0}'".format(obj.text))
-                #print("ASAObjGroupNetwork Cannot parse '{0}'".format(obj.text))
         return retval
 
 ##
@@ -546,13 +554,21 @@ class ASAObjGroupService(ASACfgLine):
                 else:
                     retval.append(L4Object(protocol=self.protocol_type, 
                         port_spec=port_spec, syntax='asa'))
-            elif 'description ' in obj.text:
-                pass
             elif 'group-object ' in obj.text:
+                name = obj.re_match_typed(r'^\s*group-object\s+(\S+)', group=1, 
+                    result_type=str)
+                group_ports = self.confobj.object_group_service.get(name, None)
+                if name==self.name:
+                    ## Throw an error when importing self
+                    raise ValueError("FATAL: Cannot recurse through group-object {0} in object-group service {1}".format(name, self.name))
+                if (group_ports is None):
+                    raise ValueError("FATAL: Cannot find group-object named {0}".format(name))
+                else:
+                    retval.extend(group_ports.ports)
+            elif 'description ' in obj.text:
                 pass
             else:
                 raise NotImplementedError("Cannot parse '{0}'".format(obj.text))
-                #print("ASAObjGroupService Cannot parse '{0}'".format(obj.text))
         return retval
 
 ##
